@@ -177,9 +177,9 @@ class PreseemGrpcClient(object):
             except Exception as err:
                 logging.exception('Error calling grpc service')
 
-    def _grpc_op_collect(self, op, *args):
+    def _grpc_op_collect(self, op, req, metadata):
         """Run a GRPC operation and collect the results in this thread."""
-        r = op(*args)
+        r = op(req, metadata=metadata)
         try:
             iterator = iter(r)  # this is to detect whether its a sequence
             return [x for x in iterator]  # this does network i/o
@@ -187,7 +187,7 @@ class PreseemGrpcClient(object):
             pass
         return r
 
-    async def _grpc_op(self, op, req, num_retries=5, timeout=None, collect_results=None):
+    async def _grpc_op(self, op, req, num_retries=5, timeout=None, collect_results=None, metadata=None):
         loop = asyncio.get_event_loop()
         for retry_num in range(num_retries + 1):
             if retry_num > 0:
@@ -197,17 +197,17 @@ class PreseemGrpcClient(object):
                 if timeout:
                     try:
                         if collect_results:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  self._grpc_op_collect, op, req), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  self._grpc_op_collect, op, req, metadata), timeout=timeout)
                         else:
-                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  op, req), timeout=timeout)
+                            return await asyncio.wait_for(loop.run_in_executor(self._executor,  op, req, metadata=metadata), timeout=timeout)
                     except asyncio.TimeoutError:
                         logging.warning('GRPC operation timed out: %s', op)
                         raise
                 else:
                     if collect_results:
-                        x = await loop.run_in_executor(self._executor, self._grpc_op_collect, op, req)
+                        x = await loop.run_in_executor(self._executor, self._grpc_op_collect, op, req, metadata)
                     else:
-                        x = await loop.run_in_executor(self._executor, op, req)
+                        x = await loop.run_in_executor(self._executor, op, req, metadata=metadata)
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
